import { FormValue } from './form.types';
/**
 * An object containing ticketing functionality.
 *
 * Use the Tickets API to create custom ticketing experiences for your events.
 *
 *  You need to have at least one existing event before getting started.
 *
 *  ### Typical Custom Ticketing Lifecycle
 *
 *  1. In the Dashboard, [create at least one ticket](https://support.wix.com/en/article/creating-tickets-for-your-event) for an event.
 *  1. Retrieve the ID of an event from the **Events/Events** collection.
 *  1. Retrieve the IDs of event tickets from the **Events/Tickets collection** using the event
 *     ID retrieved above.
 *  1. Get the event `Form` using the [`getForm()`](events.html#getForm)
 *     function with the event ID retrieved above.
 *  1. Retrieve information about the registration form inputs in the form using the [`formData`](https://dev.wix.com/docs/velo/api-reference/wix-events-frontend/form/form-data) function.
 *  1. In the Editor, add user input elements for each form input retrieved above.
 *     You may want to set the elements IDs to match the names of form inputs retrieved above
 *     so that you will not have to map the names later.
 *  1. In the Editor, add elements to display the available tickets and add input elements for site visitors to select tickets.
 *  1. In the Editor, add a button that will be used to reserve ticket a site visitor selects.
 *  1. When the reserve button is clicked, gather the selected tickets
 *     and use the [`reserve()`](https://dev.wix.com/docs/velo/api-reference/wix-events-frontend/tickets/reserve) function to reserve the tickets. The function
 *     creates a reservation ID to be used later.
 *  1. In the Editor, add a button that will be used to checkout reserved tickets.
 *  1. When the checkout button is clicked, gather the values entered into the form in
 *     a `FormValue` array and use [`checkout()`](https://dev.wix.com/docs/velo/api-reference/wix-events-frontend/tickets/checkout)
 *     function to checkout the reservation. The function creates an order.
 *  1. Use the payment ID from the order created above to call the Wix Pay API's [`startPayment()`](https://dev.wix.com/docs/velo/api-reference/wix-pay-frontend/start-payment)
 *     function to complete the payment process.
 *  1. Display the link to the tickets as a PDF.
 */
export interface Tickets {
    /**
     * Performs a checkout on reserved tickets.
     *
     * The `checkout()` function returns a Promise that resolves to a
     *  `CheckoutResponse` when the ticket reservation
     *  has been checked out.
     *
     *  To checkout tickets, you must first call the [`reserve()`](https://dev.wix.com/docs/velo/api-reference/wix-events-frontend/tickets/reserve) function
     *  to reserve the tickets.
     *
     *  Use the returned `order` to process payment for the tickets by passing the `order`'s
     *  `paymentId` to the [`startPayment()`](https://dev.wix.com/docs/velo/api-reference/wix-pay-frontend/start-payment) function. Note that
     *  since the `order` has a `paymentId`, you do not need to first call [`createPayment()`](https://dev.wix.com/docs/velo/api-reference/wix-pay-backend/create-payment)
     *  to create a payment.
     *
     *  Before using the startPayment() function, you will need to set up your site to
     *  accept payments. To learn more, see [About Accepting Payments](https://support.wix.com/en/article/about-accepting-payments).
     *  When setting up your site to accept payments, be sure to select the payment
     *  methods you want to offer and [set your payment currency](https://support.wix.com/en/article/setting-your-currency-for-accepting-payments).
     *
     *
     * > **Notes:**
     * > * To work with the Wix Events API, you need to publish your site.
     * > * With this function it's not possible to have separate ticket reservation forms for each ticket. You can only have 1 reservation form per ticket order.
     * @param eventId - ID of the event that the ticket reservations are for.
     * @requiredField eventId
     * @param reservationId - ID of the ticket reservations.
     * @requiredField reservationId
     * @param checkoutInfo - Information related to the checkout.
     * @requiredField checkoutInfo
     * @servicePath wix-events-frontend.Tickets.CheckoutInfo
     * @returns Fulfilled - Information about the checkout that was performed.
     * @servicePath wix-events-frontend.Tickets.CheckoutResponse
     */
    checkout(eventId: string, reservationId: string, checkoutInfo: CheckoutInfo): Promise<CheckoutResponse>;
    /**
     * Reserves tickets for an event.
     *
     * The `reserve()` function returns a Promise that resolves to a
     *  `ReservationResponse` when the tickets have been reserved.
     *
     *  Retrieve ticket IDs to specify which tickets to reserve from the **Events/Tickets** collection. Each ticket must have a unique ID.
     * > **Notes:**
     * > - To work with the Wix Events API, you need to publish your site.
     * > - This function doesn't reserve tickets for events with seating maps.
     * @param eventId - ID of the event to reserve tickets for.
     * @requiredField eventId
     * @param tickets - Tickets to reserve.
     * @requiredField tickets
     * @servicePath wix-events-frontend.Tickets.TicketSelection
     * @returns Fulfilled - Information about the reservations that were created.
     * @servicePath wix-events-frontend.Tickets.ReservationResponse
     */
    reserve(eventId: string, tickets: TicketSelection[]): Promise<ReservationResponse>;
    /**
     * Updates a ticket order.
     *
     * The `updateOrder()` function returns a Promise that resolves to an
     *  `UpdateOrderResponse` when the ticket order
     *  has been updated with the new form values specified in the `updateInfo` parameter.
     *
     *  You cannot update an order after payment has been processed.
     *
     * > **Note:**
     *  To work with the Wix Events API, you need to publish your site.
     * @param eventId - ID of the event that the ticket reservations are for.
     * @requiredField eventId
     * @param orderNumber - Number of the order to update.
     * @requiredField orderNumber
     * @param updateInfo - Information related to the update.
     * @requiredField updateInfo
     * @servicePath wix-events-frontend.Tickets.UpdateInfo
     * @returns Fulfilled - Information about the order that was updated.
     * @servicePath wix-events-frontend.Tickets.UpdateOrderResponse
     */
    updateOrder(eventId: string, orderNumber: string, updateInfo: UpdateInfo): Promise<UpdateOrderResponse>;
    /**
     * Verifies a ticket coupon.
     *
     * The `verifyCoupon()` function returns a Promise that resolves to an
     *  `VerifyCouponResponse` when the ticket coupon
     *  has been updated.
     *
     *  If the coupon has been verified, the `VerifyCouponResponse` will contain
     *  an `invoice` property with an invoice that includes the coupon discounts.
     *
     *  If the coupon fails verification, the `VerifyCouponResponse` will contain
     *  a `discountErrors` property including information about why the verification
     *  failed.
     *
     *  You may want to call the `verifyCoupon()` function in an input element's
     *  `onCustomValidation()` event
     *  handler to validate a coupon code while the form is being filled out.
     *
     * > **Note:**
     *  To work with the Wix Events API, you need to publish your site.
     * @param eventId - ID of the event that the ticket coupon is for.
     * @requiredField eventId
     * @param reservationId - ID of the reservation that the ticket coupon is for.
     * @requiredField reservationId
     * @param coupon - Code of the coupon to verify.
     * @requiredField coupon
     * @returns Fulfilled - Information about coupon verification.
     * @servicePath wix-events-frontend.Tickets.VerifyCouponResponse
     */
    verifyCoupon(eventId: string, reservationId: string, coupon: string): Promise<VerifyCouponResponse>;
}
/**
 * An object containing information about a checkout.
 */
export interface CheckoutInfo {
    /**
     * Field names and values for a registration form.
     * @requiredField formValues
     * @servicePath wix-events-frontend.Form.FormValue
     */
    formValues: FormValue[];
    /**
     * Coupon to be used during checkout.
     */
    coupon?: string;
}
/**
 * An object containing information about a checkout performed using the [`checkout()`](https://dev.wix.com/docs/velo/api-reference/wix-events-frontend/tickets/reserve) function.
 */
export interface CheckoutResponse {
    /**
     * Ticket reservations.
     * @requiredField reservations
     * @servicePath wix-events-frontend.Tickets.Reservation
     */
    reservations: Reservation[];
    /**
     * Ticket order.
     * @requiredField order
     * @servicePath wix-events-frontend.Tickets.Order
     */
    order: Order;
    /**
     * Time the reservations expire.
     * @requiredField expirationTime
     */
    expirationTime: Date;
}
/**
 * An object representing a discount.
 */
export interface Discount {
    /**
     * Discount amount.
     * @requiredField amount
     * @servicePath wix-events-frontend.Tickets.Money
     */
    amount: Money;
    /**
     * Amount after discount.
     * @requiredField afterDiscount
     * @servicePath wix-events-frontend.Tickets.Money
     */
    afterDiscount: Money;
    /**
     * Discount code.
     * @requiredField code
     */
    code: string;
    /**
     * Discount name.
     * @requiredField name
     */
    name: string;
    /**
     * ID of the coupon used in the discount.
     * @requiredField couponId
     */
    couponId: string;
}
/**
 * An object containing information about a discount error.
 */
export interface DiscountError {
    /**
     * Error code.
     *
     * One of:
     *
     * + `"ERROR_COUPON_DOES_NOT_EXIST"`
     * + `"ERROR_COUPON_IS_DISABLED"`
     * + `"ERROR_COUPON_USAGE_EXCEEDED"`
     * + `"ERROR_COUPON_HAS_EXPIRED"`
     * @requiredField code
     */
    code: string;
}
/**
 * An object containing information about discount errors.
 */
export interface DiscountErrors {
    /**
     * Invoice the coupon is used in.
     * @requiredField error
     * @servicePath wix-events-frontend.Tickets.DiscountError
     */
    error: DiscountError[];
}
/**
 * An object representing a fee.
 */
export interface Fee {
    /**
     * Fee name. Value is `"WIX_FEE"`: Wix service fee applied to the item.
     * @requiredField name
     */
    name: string;
    /**
     * Fee calculation method.
     *  One of:
     *
     *  + `"FEE_ADDED"`: Fee is added to the ticket price at checkout.
     *  + `"FEE_INCLUDED"`: Seller absorbs the fee. It is deducted from the ticket price.
     * @requiredField type
     */
    type: string;
    /**
     * Rate percentage. Possible values are between `"0.01"` and `"100"`, using up to 2 decimal places.
     * @requiredField rate
     */
    rate: string;
    /**
     * Total amount of fee charges.
     * @requiredField amount
     * @servicePath wix-events-frontend.Tickets.Money
     */
    amount: Money;
}
/**
 * An object representing a ticket order invoice.
 */
export interface Invoice {
    /**
     * Invoice items.
     * @requiredField items
     * @servicePath wix-events-frontend.Tickets.InvoiceItem
     */
    items: InvoiceItem[];
    /**
     * Invoice total.
     * @requiredField total
     * @servicePath wix-events-frontend.Tickets.Money
     */
    total: Money;
    /**
     * Invoice applied discount.
     * @servicePath wix-events-frontend.Tickets.Discount
     */
    discount?: Discount;
    /**
     * Invoice tax.
     * @servicePath wix-events-frontend.Tickets.Tax
     */
    tax?: Tax;
    /**
     * Invoice subtotal amount before discount, tax, and fees.
     * @requiredField subTotal
     * @servicePath wix-events-frontend.Tickets.Money
     */
    subTotal: Money;
    /**
     * Invoice total amount after discount, tax, and fees.
     *  Grand total is calculated in the following manner:
     *
     *  1. Total price of all items in the cart.
     *  2. Discount is subtracted from the cart (if applicable).
     *  3. Tax is added (if applicable).
     *  4. Wix service fee is added.
     * @requiredField grandTotal
     * @servicePath wix-events-frontend.Tickets.Money
     */
    grandTotal: Money;
    /**
     * Invoice applied fee charges.
     * @requiredField fees
     * @servicePath wix-events-frontend.Tickets.Fee
     */
    fees: Fee[];
    /**
     * Total revenue with taxes, excluding fees. Payment provider fees are not deducted.
     * @requiredField revenue
     * @servicePath wix-events-frontend.Tickets.Money
     */
    revenue: Money;
}
/**
 * An object representing a ticket order invoice item.
 */
export interface InvoiceItem {
    /**
     * Invoice item ID.
     * @requiredField id
     */
    id: string;
    /**
     * Invoice item quantity.
     * @requiredField quantity
     */
    quantity: number;
    /**
     * Invoice item name.
     * @requiredField name
     */
    name: string;
    /**
     * Invoice item price.
     * @requiredField price
     * @servicePath wix-events-frontend.Tickets.Money
     */
    price: Money;
    /**
     * Invoice item total.
     * @requiredField total
     * @servicePath wix-events-frontend.Tickets.Money
     */
    total: Money;
    /**
     * Invoice item applied discount.
     * @servicePath wix-events-frontend.Tickets.Discount
     */
    discount?: Discount;
    /**
     * Invoice item tax.
     * @servicePath wix-events-frontend.Tickets.Tax
     */
    tax?: Tax;
    /**
     * Invoice item applied fee charges.
     * @requiredField fees
     * @servicePath wix-events-frontend.Tickets.Fee
     */
    fees: Fee[];
}
/**
 * An object representing a monetary amount.
 */
export interface Money {
    /**
     * Decimal amount.
     * @requiredField amount
     */
    amount: string;
    /**
     * ISO 4217 currency format. For example, "USD".
     * @requiredField currency
     */
    currency: string;
}
/**
 * An object containing information about a ticket order.
 */
export interface Order {
    /**
     * Order number.
     * @requiredField orderNumber
     */
    orderNumber: string;
    /**
     * ID of the reservation used in the order.
     * @requiredField reservationId
     */
    reservationId: string;
    /**
     * ID of the checkout payment.
     * @requiredField paymentId
     */
    paymentId: string;
    /**
     * ID of the event the tickets are for.
     * @requiredField eventId
     */
    eventId: string;
    /**
     * ID of the contact associated with the order.
     * @requiredField contactId
     */
    contactId: string;
    /**
     * ID of the member associated with the order.
     * @requiredField memberId
     */
    memberId: string;
    /**
     * Time the order was created.
     * @requiredField createdDate
     */
    createdDate: string;
    /**
     * First name associated with the order.
     * @requiredField firstName
     */
    firstName: string;
    /**
     * Last name associated with the order.
     * @requiredField lastName
     */
    lastName: string;
    /**
     * Full name associated with the order.
     * @requiredField fullName
     */
    fullName: string;
    /**
     * Email address associated with the order.
     * @requiredField email
     */
    email: string;
    /**
     * Form values used in the order.
     * @requiredField checkoutForm
     * @servicePath wix-events-frontend.Form.FormValue
     */
    checkoutForm: FormValue[];
    /**
     * Whether the order is confirmed.
     * @requiredField confirmed
     */
    confirmed: boolean;
    /**
     * Status of the order.
     *
     * One of:
     *
     * + `"INITIATED"`
     * + `"FREE"`
     * + `"PENDING"`
     * + `"PAID"`
     * + `"OFFLINE_PENDING"`
     * @requiredField status
     */
    status: string;
    /**
     * Payment method.
     * @requiredField paymentMethod
     */
    paymentMethod: string;
    /**
     * Number of tickets in the order.
     * @requiredField ticketQuantity
     */
    ticketQuantity: number;
    /**
     * Order price.
     * @requiredField price
     * @servicePath wix-events-frontend.Tickets.Money
     */
    price: Money;
    /**
     * URL of the tickets PDF.
     * @requiredField ticketsPdf
     */
    ticketsPdf: string;
    /**
     * Whether the order is archived.
     * @requiredField archived
     */
    archived: boolean;
    /**
     * Indicates whether personal information has been removed.
     * @requiredField anonymized
     */
    anonymized: boolean;
    /**
     * Order invoice.
     * @requiredField invoice
     * @servicePath wix-events-frontend.Tickets.Invoice
     */
    invoice: Invoice;
    /**
     * Whether all ticket holders in the order have checked in.
     * @requiredField fullyCheckedIn
     */
    fullyCheckedIn: boolean;
    /**
     * Transaction ID.
     * @requiredField transactionId
     */
    transactionId: string;
}
/**
 * An object representing ticket reservations.
 */
export interface Reservation {
    /**
     * Ticket quantity.
     * @requiredField quantity
     */
    quantity: number;
    /**
     * Reserved ticket.
     * @requiredField ticket
     * @servicePath wix-events-frontend.Tickets.Ticket
     */
    ticket: Ticket;
}
/**
 * An object containing information about a reservation created using the [`reserve()`](https://dev.wix.com/docs/velo/api-reference/wix-events-frontend/tickets/reserve) function.
 */
export interface ReservationResponse {
    /**
     * Reservation ID.
     * @requiredField id
     */
    id: string;
    /**
     * Ticket reservations.
     * @requiredField reservations
     * @servicePath wix-events-frontend.Tickets.Reservation
     */
    reservations: Reservation[];
    /**
     * Ticket reservations invoice.
     * @requiredField invoice
     * @servicePath wix-events-frontend.Tickets.Invoice
     */
    invoice: Invoice;
    /**
     * Time the reservations expire.
     * @requiredField expirationTime
     */
    expirationTime: Date;
}
/**
 * An object representing a tax.
 */
export interface Tax {
    /**
     * Tax type.
     *  One of:
     *
     *  + `"INCLUDED"`: Tax is included in the ticket price.
     *  + `"ADDED"`: Tax is added to the order at checkout.
     * @requiredField type
     */
    type: string;
    /**
     * Tax name.
     * @requiredField name
     */
    name: string;
    /**
     * Rate percentage. Possible values are between `"0.01"` and `"100"`, using up to 2 decimal places.
     * @requiredField rate
     */
    rate: string;
    /**
     * Taxable amount.
     * @requiredField taxable
     * @servicePath wix-events-frontend.Tickets.Money
     */
    taxable: Money;
    /**
     * Total tax amount.
     * @requiredField amount
     * @servicePath wix-events-frontend.Tickets.Money
     */
    amount: Money;
}
/**
 * An object representing a ticket.
 */
export interface Ticket {
    /**
     * Ticket ID.
     * @requiredField _id
     */
    _id: number;
    /**
     * Ticket price.
     * @requiredField price
     * @servicePath wix-events-frontend.Tickets.Money
     */
    price: Money;
    /**
     * Whether the ticket is free.
     * @requiredField free
     */
    free: boolean;
    /**
     * Ticket name.
     * @requiredField name
     */
    name: string;
    /**
     * Ticket description.
     * @requiredField description
     */
    description: string;
    /**
     * Number of tickets that can be checked out together.
     *  A value of `0` means there is no limit.
     * @requiredField limitPerCheckout
     */
    limitPerCheckout: number;
    /**
     * Order index.
     * @requiredField orderIndex
     */
    orderIndex: number;
    /**
     * Ticket policy rules.
     * @requiredField policy
     */
    policy: string;
    /**
     * ID of the event the ticket is for.
     * @requiredField eventId
     */
    eventId: string;
}
/**
 * An object representing an event ticket.
 */
export interface TicketSelection {
    /**
     * ID of the ticket.
     * @requiredField ticketId
     */
    ticketId: string;
    /**
     * Ticket quantity.
     * @requiredField quantity
     */
    quantity: number;
}
/**
 * An object containing information about an order update.
 */
export interface UpdateInfo {
    /**
     * Field names and values for a registration form.
     * @requiredField formValues
     * @servicePath wix-events-frontend.Form.FormValue
     */
    formValues: FormValue[];
}
/**
 * An object containing information about an order updated using the [`updateOrder()`](#updateOrder) function.
 */
export interface UpdateOrderResponse {
    /**
     * Updated ticket order.
     * @requiredField order
     * @servicePath wix-events-frontend.Tickets.Order
     */
    order: Order;
}
/**
 * An object containing information about a coupon being verified using the [`verifyCoupon()`](#verifyCoupon) function.
 */
export interface VerifyCouponResponse {
    /**
     * Invoice the coupon is used in.
     * @servicePath wix-events-frontend.Tickets.Invoice
     */
    invoice?: Invoice;
    /**
     * Discount errors.
     * @servicePath wix-events-frontend.Tickets.DiscountErrors
     */
    discountErrors?: DiscountErrors;
}
/**
 * Performs a checkout on reserved tickets.
 *
 * The `checkout()` function returns a Promise that resolves to a
 *  `CheckoutResponse` when the ticket reservation
 *  has been checked out.
 *
 *  To checkout tickets, you must first call the [`reserve()`](https://dev.wix.com/docs/velo/api-reference/wix-events-frontend/tickets/reserve) function
 *  to reserve the tickets.
 *
 *  Use the returned `order` to process payment for the tickets by passing the `order`'s
 *  `paymentId` to the [`startPayment()`](https://dev.wix.com/docs/velo/api-reference/wix-pay-frontend/start-payment) function. Note that
 *  since the `order` has a `paymentId`, you do not need to first call [`createPayment()`](https://dev.wix.com/docs/velo/api-reference/wix-pay-backend/create-payment)
 *  to create a payment.
 *
 *  Before using the startPayment() function, you will need to set up your site to
 *  accept payments. To learn more, see [About Accepting Payments](https://support.wix.com/en/article/about-accepting-payments).
 *  When setting up your site to accept payments, be sure to select the payment
 *  methods you want to offer and [set your payment currency](https://support.wix.com/en/article/setting-your-currency-for-accepting-payments).
 *
 *
 * > **Notes:**
 * > * To work with the Wix Events API, you need to publish your site.
 * > * With this function it's not possible to have separate ticket reservation forms for each ticket. You can only have 1 reservation form per ticket order.
 * @param eventId - ID of the event that the ticket reservations are for.
 * @requiredField eventId
 * @param reservationId - ID of the ticket reservations.
 * @requiredField reservationId
 * @param checkoutInfo - Information related to the checkout.
 * @requiredField checkoutInfo
 * @servicePath wix-events-frontend.Tickets.CheckoutInfo
 * @returns Fulfilled - Information about the checkout that was performed.
 * @servicePath wix-events-frontend.Tickets.CheckoutResponse
 */
export function checkout(eventId: string, reservationId: string, checkoutInfo: CheckoutInfo): Promise<CheckoutResponse>;
/**
 * Reserves tickets for an event.
 *
 * The `reserve()` function returns a Promise that resolves to a
 *  `ReservationResponse` when the tickets have been reserved.
 *
 *  Retrieve ticket IDs to specify which tickets to reserve from the **Events/Tickets** collection. Each ticket must have a unique ID.
 * > **Notes:**
 * > - To work with the Wix Events API, you need to publish your site.
 * > - This function doesn't reserve tickets for events with seating maps.
 * @param eventId - ID of the event to reserve tickets for.
 * @requiredField eventId
 * @param tickets - Tickets to reserve.
 * @requiredField tickets
 * @servicePath wix-events-frontend.Tickets.TicketSelection
 * @returns Fulfilled - Information about the reservations that were created.
 * @servicePath wix-events-frontend.Tickets.ReservationResponse
 */
export function reserve(eventId: string, tickets: TicketSelection[]): Promise<ReservationResponse>;
/**
 * Updates a ticket order.
 *
 * The `updateOrder()` function returns a Promise that resolves to an
 *  `UpdateOrderResponse` when the ticket order
 *  has been updated with the new form values specified in the `updateInfo` parameter.
 *
 *  You cannot update an order after payment has been processed.
 *
 * > **Note:**
 *  To work with the Wix Events API, you need to publish your site.
 * @param eventId - ID of the event that the ticket reservations are for.
 * @requiredField eventId
 * @param orderNumber - Number of the order to update.
 * @requiredField orderNumber
 * @param updateInfo - Information related to the update.
 * @requiredField updateInfo
 * @servicePath wix-events-frontend.Tickets.UpdateInfo
 * @returns Fulfilled - Information about the order that was updated.
 * @servicePath wix-events-frontend.Tickets.UpdateOrderResponse
 */
export function updateOrder(eventId: string, orderNumber: string, updateInfo: UpdateInfo): Promise<UpdateOrderResponse>;
/**
 * Verifies a ticket coupon.
 *
 * The `verifyCoupon()` function returns a Promise that resolves to an
 *  `VerifyCouponResponse` when the ticket coupon
 *  has been updated.
 *
 *  If the coupon has been verified, the `VerifyCouponResponse` will contain
 *  an `invoice` property with an invoice that includes the coupon discounts.
 *
 *  If the coupon fails verification, the `VerifyCouponResponse` will contain
 *  a `discountErrors` property including information about why the verification
 *  failed.
 *
 *  You may want to call the `verifyCoupon()` function in an input element's
 *  `onCustomValidation()` event
 *  handler to validate a coupon code while the form is being filled out.
 *
 * > **Note:**
 *  To work with the Wix Events API, you need to publish your site.
 * @param eventId - ID of the event that the ticket coupon is for.
 * @requiredField eventId
 * @param reservationId - ID of the reservation that the ticket coupon is for.
 * @requiredField reservationId
 * @param coupon - Code of the coupon to verify.
 * @requiredField coupon
 * @returns Fulfilled - Information about coupon verification.
 * @servicePath wix-events-frontend.Tickets.VerifyCouponResponse
 */
export function verifyCoupon(eventId: string, reservationId: string, coupon: string): Promise<VerifyCouponResponse>;
